@@ -53,10 +53,6 @@
 #include <sipwitch/mapped.h>
 #endif
 
-#ifndef	_SIPWITCH_RTPPROXY_H_
-#include <sipwitch/rtpproxy.h>
-#endif
-
 #ifndef	_SIPWITCH_PROCESS_H_
 #include <sipwitch/process.h>
 #endif
@@ -152,6 +148,7 @@ public:
 		static int sip_protocol;
 		static int sip_family;
 		static int sip_tlsmode;
+		static const char *sip_domain;
 
         callback(int level = 0);
         virtual ~callback();
