@@ -659,6 +659,21 @@ bool server::isLocal(struct sockaddr *addr)
 	return rtn;
 }
 
+stack::subnet *server::getSubnet(const char *id)
+{
+	locking.access();
+
+	linked_pointer<stack::subnet> np = (((server *)(cfg))->acl);
+	
+	while(is(np)) {
+		if(String::equal(np->getId(), id))
+			return *np;
+		np.next();
+	}
+	locking.release();
+	return NULL;
+} 
+
 stack::subnet *server::getPolicy(struct sockaddr *addr)
 {
 	assert(addr != NULL);
@@ -1164,7 +1179,7 @@ invalid:
 			if(argc != 2)
 				goto invalid;
 			state = String::unquote(argv[1], "\"\"\'\'()[]{}");
-			rtpproxy::publish(state);
+			service::publish(state);
 			process::errlog(NOTICE, "published address is %s", state);
 			continue;
 		}
