@@ -16,6 +16,7 @@
 #include <sipwitch/sipwitch.h>
 #include <eXosip2/eXosip.h>
 #include <config.h>
+#include <ctype.h>
 
 #ifndef	SESSION_EXPIRES
 #define	SESSION_EXPIRES	"session-expires"
@@ -29,6 +30,8 @@
 #define	ALLOW_EVENTS	"allow-events"
 #endif
 
+#define	P_SIPWITCH_NODE	"P-sipwitch-node"
+
 #define	SECOND_TIMEOUT	(1000l)
 #define	MINUTE_TIMEOUT	(SECOND_TIMEOUT * 60l)
 #define	HOUR_TIMEOUT	(MINUTE_TIMEOUT * 60l)
@@ -184,6 +187,7 @@ public:
 	inline static unsigned getRoutes(void)
 		{return reg.routes;};
 
+	static const char *getDomain(void);
 	static void incUse(mapped *rr, stats::stat_t stat);
 	static void decUse(mapped *rr, stats::stat_t stat);
 	static unsigned getEntries(void);
@@ -211,6 +215,7 @@ private:
 	friend class proxy;
 	friend class thread;
 	friend class messages;
+	friend class media;
 
 	class call;
 
@@ -248,7 +253,7 @@ private:
 
 		enum {OPEN, CLOSED, RING, BUSY, REORDER, REFER, REINVITE} state;
 
-		char sdp[1024];					// sdp body to use in exchange
+		char sdp[MAX_SDP_BUFFER];		// sdp body to use in exchange
 		char identity[MAX_URI_SIZE];	// our effective contact/to point...
 		char sysident[MAX_IDENT_SIZE];	// ident of this session
 		char display[MAX_DISPLAY_SIZE];	// callerid reference field
@@ -256,6 +261,7 @@ private:
 		char from[MAX_URI_SIZE + MAX_DISPLAY_SIZE];	// formatted from line for endpoint
 		char uuid[48];
 
+		LinkedObject *nat;				// media nat chain...
 		struct sockaddr_storage peering;
 
 		char authid[MAX_USERID_SIZE];	// for authentication...
@@ -301,7 +307,6 @@ private:
 		char dialed[MAX_IDENT_SIZE];	// user or ip address...
 		char subject[MAX_URI_SIZE];		// call subject
 		char request[MAX_URI_SIZE];		// requesting identity for refer flip
-		rtpproxy *rtp;
 
 		void disarm(void);
 		void arm(timeout_t timeout);
@@ -325,7 +330,7 @@ private:
 		void refer(thread *thread, session *s);
 		void bye(thread *thread, session *s);
 		void set(state_t state, char id, const char *text);
-		
+
 		OrderedIndex segments;
 		const char *reason;
 		const char *joined;
@@ -365,7 +370,6 @@ private:
 
 	volatile int timing;
 
-	const char *volatile domain;
 	const char *volatile localnames;
 	const char *volatile restricted;
 	const char *volatile trusted;
@@ -423,7 +427,6 @@ public:
 	static void release(MappedCall *map);
 	static MappedCall *get(void);
 	static bool forward(stack::call *cr);
-	static bool assign(stack::call *cr, unsigned count);
 	static void inviteRemote(stack::session *session, const char *uri, const char *digest = NULL);
 	static void inviteLocal(stack::session *session, registry::mapped *rr, destination_t dest);
 	
@@ -470,6 +473,7 @@ public:
 	static void getDialing(const char *id, usernode& user);
 	static keynode *getConfig(void);
 	static stack::subnet *getPolicy(struct sockaddr *addr);
+	static stack::subnet *getSubnet(const char *id);
 	static bool isLocal(struct sockaddr *addr);
 	static void release(stack::subnet *access);
 	static void release(keynode *node);
@@ -551,6 +555,7 @@ private:
 	MappedRegistry *accepted;
 	eXosip_event_t *sevent;
 	char buffer[MAX_URI_SIZE];	
+	char buftemp[MAX_URI_SIZE];
 	char identbuf[MAX_USERID_SIZE + 12];
 	char identity[MAX_USERID_SIZE];
 	char dialing[MAX_USERID_SIZE];
@@ -604,5 +609,107 @@ public:
 	static void shutdown(void);
 };
 
+// media proxy support for NAT transversal is being moved to here...
+class __LOCAL media : public service::callback
+{
+public:
+	// support thread
+	class __LOCAL thread : public DetachedThread
+	{
+	public:
+		static void startup(void);
+
+		static void notify(void);	
+
+		static void shutdown(void);
+
+	private:
+		thread();
+
+		void run(void);
+	};
+
+	// a support class to help in sdp parsing
+	class __LOCAL sdp
+	{
+	public:
+		const char *bufdata;
+		char *outdata, *result;
+		size_t buflen, outpos;
+		struct sockaddr *peering;
+		struct sockaddr_storage local, top;
+		LinkedObject **nat;
+		unsigned mediacount;
+		unsigned short mediaport;
+
+		sdp();
+		sdp(const char *source, char *target, size_t len = MAX_SDP_BUFFER);
+
+		inline struct sockaddr *get(void)
+			{return (struct sockaddr *)&local;};
+
+		void set(const char *source, char *target, size_t len = MAX_SDP_BUFFER);
+		char *get(char *buffer, size_t len);
+		size_t put(char *buffer);
+
+		// check connect in sdp output
+		void check_connect(char *buffer, size_t len);
+		void check_media(char *buffer, size_t len);
+
+		// can do backfill of NAT if connect in media record
+		void reconnect(void);
+	};
+
+	// proxy socket class
+	class __LOCAL proxy : public LinkedObject
+	{
+	public:
+		socket_t so;
+		time_t expires;
+		uint16_t port;
+		struct sockaddr_storage local, remote, peering;
+		bool fw;	// to be used when we add ipfw rules support
+
+		proxy();		
+		~proxy();
+
+		bool activate(media::sdp *parser);
+		void release(time_t expire = 0l);
+		void reconnect(struct sockaddr *address);
+		void copy(void);
+	};
+	
+	media();
+
+	void start(service *cfg);
+	void stop(service *cfg);
+	void reload(service *cfg);
+
+	// get and activate nat instance if any are free...
+	static proxy *get(media::sdp *parser);
+
+	// set ipv6 flag, removes need to proxy any external addresses...
+	static void enableIPV6(void);
+
+	// release any existing media proxy for the call session, proxy can be kept active for re-invite transition
+	static void release(LinkedObject **nat, unsigned expires = 0);
+
+	// rewrite an invite for a call target if different, otherwise uses original source sdp...
+	static char *invite(stack::session *session, const char *target, LinkedObject **nat, char *sdp, size_t size = MAX_SDP_BUFFER);
+
+	// rewrite or copy sdp of session on answer for connection
+	static char *answer(stack::session *session, const char *sdp); 
+
+	// re-assign or copy sdp on re-invite; clears and rebuilds media proxy if needed...
+	static char *reinvite(stack::session *session, const char *sdp);
+
+private:
+	// low level rewrite & proxy assignment
+	static char *rewrite(media::sdp *parser);
+
+	// see if connected directly or if requires proxy
+	static bool isProxied(const char *source, const char *target, struct sockaddr_storage *peering);
+};
+
 END_NAMESPACE
 
