@@ -1338,12 +1338,20 @@ static void server_realm(void)
 	if(params.argc != 0)
 		fault(3, "Invalid Parameters");
 
-	fsys::open(fd, "/etc/siprealm", fsys::ACCESS_RDONLY);
+	fsys::open(fd, DEFAULT_CFGPATH "/siprealm", fsys::ACCESS_RDONLY);
+	if(!is(fd))
+		fsys::open(fd, DEFAULT_VARPATH "/lib/sipwitch/uuid", fsys::ACCESS_RDONLY);
+
 	if(is(fd)) {
 		memset(realm, 0, sizeof(realm));
 		fsys::read(fd, realm, sizeof(realm) - 1);
 		fsys::close(fd);
-		char *cp = strchr(realm, ':');
+
+		char *cp = strchr(realm, '\n');
+		if(cp)
+			*cp = 0;
+
+		cp = strchr(realm, ':');
 		if(cp)
 			*cp = 0;
 	}
